@@ -37,7 +37,7 @@
 #  ifndef unix
 #    define DEFDICT "words"
 #  else
-#    define DEFDICT "/usr/dict/words"
+#    define DEFDICT "/usr/share/dict/words"
 #  endif
 #endif
 
